#!/usr/bin/env python
#coding=utf-8

import onelab
import math, os
import string

OL = onelab.client(__file__)

OL.openProject(OL.checkPath('BCImpact/grid/grid.geo'))

# Definition of boundary conditions
BCUInlet = OL.defineString('Foam/BC/BCUInlet', value='fixedValue', 
	choices = {'fixedValue','zeroGradient'}, label='Velocity inlet')
BCUOutlet = OL.defineString('Foam/BC/BCUOutlet', value='zeroGradient', 
	choices = {'fixedValue','zeroGradient'}, label='Velocity outlet')
BCPInlet = OL.defineString('Foam/BC/BCPInlet', value='fixedValue', 
	choices = {'fixedValue','zeroGradient'}, label='Pressure inlet')
BCPOutlet = OL.defineString('Foam/BC/BCPOutlet', value='fixedValue', 
	choices = {'fixedValue','zeroGradient'}, label='Pressure outlet')

OL.defineString('Foam/caseOK', label='Computable', readOnly = 1)

if ((BCUInlet == 'zeroGradient') & (BCUOutlet == 'zeroGradient')) | ((BCPInlet == 'zeroGradient') & (BCPOutlet == 'zeroGradient')):
    OL.setString('Foam/caseOK', value='No! set a Dirichlet BC for U & p',
                 attributes={'Highlight':'IndianRed'})
else:
    OL.setString('Foam/caseOK', value='Yes!',
                  attributes={'Highlight':'Aquamarine'})

# Preprocess OpenFOAM input files
OL.preProcess('foam', OL.checkPath('BCImpact/modifiedFiles/U.ol'))
OL.preProcess('foam', OL.checkPath('BCImpact/modifiedFiles/p.ol'))

if OL.action == 'check' :
    exit(1)

OL.run('mesher', 'gmsh '+ OL.checkPath('BCImpact/grid/grid.geo'),'-3')
OL.mergeFile(OL.checkPath('BCImpact/grid/grid.msh'))

# Run OpenFOAM
OL.call('foam','bash runBCImpact.sh', rundir=OL.wdir)

OL.mergeFile(OL.checkPath('p_constantPlane.pos'))
OL.mergeFile(OL.checkPath('U_constantPlane.pos'))

exit(1)






