#!/usr/bin/env python
#coding=utf-8

import onelab
import math, os, sys

OL = onelab.client(__file__)

OL.openProject(OL.checkPath('meshImpact/grid/grid.geo'))

radiusMesh = OL.getNumber('Foam/Geometry/radiusMesh')
print('radius = %g' %radiusMesh)

OL.defineNumber('Foam/Solution/cd', label='Drag Coefficient [-]', 
            attributes={'Highlight':'Coral'})
OL.defineNumber('Foam/Solution/cl', label='Lift Coefficient [-]', 
            attributes={'Highlight':'Coral'})

# We're done with the "check" phase
if OL.action == 'check' :
    exit(1)

OL.run('mesher', 'gmsh ' +  OL.checkPath('meshImpact/grid/grid.geo'),'-3')
OL.mergeFile(OL.checkPath('meshImpact/grid/grid.msh'))

# Run OpenFOAM case
OL.call('foam', 'bash runMeshImpact.sh', rundir=OL.wdir)

# Postprocess OpenFOAM case
OL.download(OL.checkPath('run/postProcessing/forces/0/forceCoeffs.dat'),
	    OL.getPath())
frcd = onelab.extract(OL.checkPath('forceCoeffs.dat'), -1, 2)
frcl = onelab.extract(OL.checkPath('forceCoeffs.dat'), -1, 3)

OL.addNumberChoice('Foam/Solution/cd', frcd)
OL.addNumberChoice('Foam/Solution/cl', frcl)

OL.mergeFile(OL.checkPath('p_constantPlane.pos'))
OL.mergeFile(OL.checkPath('U_constantPlane.pos'))

if OL.batch :
    sys.stderr.write('%s: Drag coef. = %12.5e (%12.5e)\n' %
                     (__file__, frcd, 1.197144e-09))
    sys.stderr.write('%s: Lift coef. = %12.5e (%12.5e)\n' %
                     (__file__, frcl, 3.407014e+00))






